@@ -7,9 +7,9 @@ Hans Buehler 2022
 from collections import OrderedDict
 from collections.abc import Mapping
 from sortedcontainers import SortedDict
-from cdxbasics.util import uniqueHash
-from cdxbasics.prettydict import PrettyDict as pdct
-from cdxbasics.logger import Logger
+from .util import uniqueHash
+from .prettydict import PrettyDict as pdct
+from .logger import Logger
 _log = Logger(__file__)
 
 class _ID(object):
@@ -17,10 +17,12 @@ class _ID(object):
 
 no_default = _ID()    # creates a unique object which can be used to detect if a default value was provided
 
+# ==============================================================================
 # New in version 0.1.45
 # Support for conditional types, e.g. we can write
 # 
 #  x = config(x, 0.1, Float >= 0., "An 'x' which cannot be negative")
+# ==============================================================================
     
 class _Cast(object):
     
@@ -42,10 +44,6 @@ class _Cast(object):
         """ Returns readable string """
         raise NotImplementedError("Internal error")
     
-# ================================
-# Flaot and Int 'cast' types
-# ================================
-
 class _Condition(_Cast):
     """ Represents a simple operator condition such as 'Float >= 0.' """
     
@@ -141,8 +139,9 @@ class _Condition(_Cast):
         return s
              
 class _CastCond(object): # NOQA
-    """ Generates _Condition's
-        See the two members Float and Int
+    """
+    Generates compound _Condition's
+    See the two members Float and Int
     """
     
     def __init__(self, cast):# NOQA
@@ -211,10 +210,13 @@ class Enum(_Cast):# NOQA
         help_cast += " ]"
         return help_cast
  
-# ================================
-# Main Config
-# ================================
 
+# ==============================================================================
+#
+# Actual Config class
+#
+# ==============================================================================
+    
 class Config(OrderedDict):
     """
     A simple Config class.
@@ -686,26 +688,11 @@ class Config(OrderedDict):
                     _log.verify( exst_value['help_default'] == help_default, "Config %s was read twice for key %s (%s) with different 'help_default' values %s and %s", self._name, key, record_key, exst_value['help_default'], help_default )                    
                     _log.verify( exst_value['help'] == help, "Config %s was read twice for key %s (%s) with different 'help' values %s and %s", self._name, key, record_key, exst_value['help'], help )
                     _log.verify( exst_value['help_cast'] == help_cast, "Config %s was read twice for key %s (%s) with different 'help_cast' values %s and %s", self._name, key, record_key, exst_value['help_cast'], help_cast )
-                    """
-                    _log.verify( exst_value['help'] == "" or help == "" or exst_value['help'] == help, "Config %s was read twice for key %s (%s) with different 'help' values %s and %s", self._name, key, record_key, exst_value['help'], help )
-                    _log.verify( exst_value['help_cast'] == "" or help_cast == "" or exst_value['help_cast'] == help_cast, "Config %s was read twice for key %s (%s) with different 'help_cast' values %s and %s", self._name, key, record_key, exst_value['help'], help )
-                    _log.verify( default == no_default or exst_value.default == no_default or exst_value['default'] == default,  "Config %s was read twice for key %s (%s) with different default values %s and %s", self._name, key, record_key, exst_value['default'], default )
-                    _log.verify( exst_value['help_default'] == "" or help_default == "" or exst_value['help_default'] == help_default, "Config %s was read twice for key %s (%s) with different 'help_default' values %s and %s", self._name, key, record_key, exst_value['help_default'], help_default )                    
-                    
-                    if exst_value['help'] == "" and help != "":
-                        exst_value['help'] = help
-                    if exst_value['help_cast'] == "" and help_cast != "":
-                        exst_value['help_cast'] = help_cast
-                    if exst_value['help_default'] == "" and help_default != "":
-                        exst_value['help_default'] = help_default
-                    """ 
         # done
         return value
         
     def __getitem__(self, key : str):
-        """
-        Returns self(key)
-        """
+        """ Returns self(key) """
         return self(key)
     def get(self, key : str, default = None ):
         """
@@ -883,21 +870,19 @@ class Config(OrderedDict):
         
     def unique_id(self) -> str:
         """
-        Returns an MDH5 hash key for this object, based on 'input_report()'
+        Returns an MDH5 hash key for this object, based on its provided inputs /not/ based on its usage
         ** WARNING **
         This function ignores any config keys or children with leading '_'.
         """
-        inputs = []      
+        inputs = {}
         for key in self:
             if key[:1] == "_":
                 continue
-            value      = self.get_raw(key)
-            hash_      = uniqueHash(key,uniqueHash(value))
-            inputs.append( hash_ )
+            inputs[key] = self.get_raw(key) 
         for c in self._children:
             if c[:1] == "_":
                 continue
-            inputs.append( uniqueHash(c,self._children[c].unique_id) )
+            inputs[c] = self._children[c].unique_id() 
         return uniqueHash(inputs)
 
     # magic
@@ -910,94 +895,7 @@ class Config(OrderedDict):
         """
         return OrderedDict.__iter__(self)
     
-        
-def test( misspell = True ):
-    """ Test function as described in README.md of the package """
-    import numpy as np
-    
-    class Test(object):
-        
-        def __init__( self, confg ):
-            # read top level parameters
-            self.features = config("features", [], list, "Features for the agent" )
-            self.weights  = config("weights", [], np.asarray, "Weigths for the agent", help_default="no initial weights")
-    
-            # Accessing children directly with member notation
-            self.activation = config.network("activation", "relu", str, "Activation function for the network")
-    
-            # Accessing via the child node
-            network  = config.network 
-            self.depth = network('depth', 10000, int, "Depth for the network") 
-            self.width = network('width', 100, int, "Width for the network")
 
-            # defer using training config to later
-            self.config_training = config.training.detach()
-            
-            # Do not forget to call <tt>done()</tt> once done with this config.
-            config.done()    # checks that we have read all keywords.
-
-        def training(self):
-
-            epochs     = self.config_training("epochs", 100, int, "Epochs for training")
-            batch_size = self.config_training("batch_size", None, help="Batch size. Use None for default of 32" )
-            self.config_training.done()
-
-    config = Config()
-    config['features']           = [ 'time', 'spot' ]
-    config.weights               = [ 1, 2, 3 ]
-    config.network.depth         = 10
-    config.network.activation    = 'relu'
-    if misspell:
-        config.network.widht         = 100   # (intentional typo)
-    else:
-        config.network.width         = 100   # (intentional typo)
-
-    test = Test(config)
-    test.training()
-    print( config.usage_report(with_cast=True) )
-    
-def test_to_kwargs():
-    """
-    Test using the ** operator.
-    This will not capture the default values provided to the function 'f'
-    """
-    
-    def f( a=1, b=2, c=3 ):
-        _ = a
-        _ = b
-        _ = c
-        
-    config = Config()
-    config.a = 10
-    config.c = 30
-    
-    f( **config )
-    config.done()
-    print( config.usage_report() )
-    
-def test_as_kwargs():
-    """
-    Test the use of config() as a good trackign tool when
-    **kwargs is used in a function
-    """
-    def g( **kwargs ):
-        kwargs = Config(kwargs)
-        a = kwargs.get("a", 100)
-        c = kwargs("c", 300)
-        d = kwargs.get("d", 100)
-        kwargs.done()
-            
-    config = Config()
-    config.a = 10
-    config.c = 30
-
-    g( **config )
-    config.done()
-    print( "g\n", config.usage_report() )
-    
-    
         
     
-        
-    
-    
+    
\ No newline at end of file
